==> ejc-wzxt-api-3.0.0-20200924.094702-5-sources.jar: com/ejianc/business/wzxt/vo/PlanDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
public class PlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal nums; // 需求数量
    private java.math.BigDecimal occupyNums; // 占用数量
    private java.math.BigDecimal surplusNums; // 剩余数量
    private java.math.BigDecimal numsAll; // 所有需求数量
    private java.math.BigDecimal occupyNumsAll; // 所有占用数量
    private java.math.BigDecimal surplusNumsAll; // 所有剩余数量
    private String memo; // 备注
    private List<PlanVO> children; //

    public List<PlanVO> getChildren() {
        return children;
    }

    public void setChildren(List<PlanVO> children) {
        this.children = children;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }

    public BigDecimal getNumsAll() {
        return numsAll;
    }

    public void setNumsAll(BigDecimal numsAll) {
        this.numsAll = numsAll;
    }

    public BigDecimal getOccupyNumsAll() {
        return occupyNumsAll;
    }

    public void setOccupyNumsAll(BigDecimal occupyNumsAll) {
        this.occupyNumsAll = occupyNumsAll;
    }

    public BigDecimal getSurplusNumsAll() {
        return surplusNumsAll;
    }

    public void setSurplusNumsAll(BigDecimal surplusNumsAll) {
        this.surplusNumsAll = surplusNumsAll;
    }
}

==> ejc-wzxt-api-3.0.0-20200925.074509-9-sources.jar: com/ejianc/business/wzxt/vo/PlanDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
public class PlanDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private java.math.BigDecimal nums; // 需求数量
    private java.math.BigDecimal occupyNums; // 占用数量
    private java.math.BigDecimal surplusNums; // 剩余数量
    private java.math.BigDecimal planNumsSum; // 所有需求数量
    private java.math.BigDecimal occupyNumsAll; // 所有占用数量
    private java.math.BigDecimal surplusNumsSum; // 所有剩余数量
    private String memo; // 备注
    private List<PlanDetailRefVO> children; //

    public List<PlanDetailRefVO> getChildren() {
        return children;
    }

    public void setChildren(List<PlanDetailRefVO> children) {
        this.children = children;
    }

    /**
     * 主表主键ID
     */
    public Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }


    public BigDecimal getOccupyNumsAll() {
        return occupyNumsAll;
    }

    public void setOccupyNumsAll(BigDecimal occupyNumsAll) {
        this.occupyNumsAll = occupyNumsAll;
    }

    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }

    public BigDecimal getSurplusNumsSum() {
        return surplusNumsSum;
    }

    public void setSurplusNumsSum(BigDecimal surplusNumsSum) {
        this.surplusNumsSum = surplusNumsSum;
    }
}
